parse_slice

Function parse_slice 

pub fn parse_slice(data: &[u8]) -> Result<Vec<Seq>, GbParserError>
Parse an entire genbank file provided as a slice. Might be slightly faster than the streaming parser used by parse_file and SeqReader::from_stream since less copying of data is required, however not as well tested. I recommend using SeqReader instead. I’ve mainly left this here for benchmarking purposes.